from setuptools import setup

setup(
    name='monotonenorm',
    version='1.0.0',
    packages=['monotonenorm'],
    url='',
    license='MIT',
    author='Ouail Kitouni, Niklas Nolte',
    author_email='kitouni@mit.edu, nnolte@mit.edu',
    description='Pytorch Implementation of constrained weight operator norms for robustness and monotonicity'
)
